==> activemq-parent-5.19.1-source-release.zip: activemq-parent-5.19.1/activemq-runtime-config/src/main/java/org/apache/activemq/plugin/jaxb2_commons/ElementAwareEqualsStrategy.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.plugin.jaxb2_commons;

import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;

/**
 * Ensure uparsed elements like spring beans referenced in the
 * xml configuration (broker plugins for example) can be
 * examined for equality
 */
public class ElementAwareEqualsStrategy extends JAXBEqualsStrategy {

    @Override
    protected boolean equalsInternal(ObjectLocator leftLocator,
                                     ObjectLocator rightLocator, Object lhs, Object rhs) {
        if (lhs instanceof Element && rhs instanceof Element) {
            final Element left = (Element) lhs;
            final Element right = (Element) rhs;
            return left.isEqualNode(right);
        } else {
            return super.equalsInternal(leftLocator, rightLocator, lhs, rhs);
        }
    }

}

==> activemq-parent-6.2.0-source-release.zip: activemq-parent-6.2.0/activemq-runtime-config/src/main/java/org/apache/activemq/plugin/jaxb2_commons/ElementAwareEqualsStrategy.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.plugin.jaxb2_commons;

import org.jvnet.jaxb.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb.locator.ObjectLocator;
import org.w3c.dom.Element;

/**
 * Ensure uparsed elements like spring beans referenced in the
 * xml configuration (broker plugins for example) can be
 * examined for equality
 */
public class ElementAwareEqualsStrategy extends JAXBEqualsStrategy {

    @Override
    protected boolean equalsInternal(ObjectLocator leftLocator,
                                     ObjectLocator rightLocator, Object lhs, Object rhs) {
        if (lhs instanceof Element && rhs instanceof Element) {
            final Element left = (Element) lhs;
            final Element right = (Element) rhs;
            return left.isEqualNode(right);
        } else {
            return super.equalsInternal(leftLocator, rightLocator, lhs, rhs);
        }
    }

}
